@@ -55,6 +55,7 @@ static void
 _vte_ft2_create(struct _vte_draw *draw, GtkWidget *widget)
 {
 	draw->impl_data = g_slice_new0(struct _vte_ft2_data);
+	gtk_widget_set_double_buffered (widget, FALSE);
 }
 
 static void
@@ -397,7 +398,7 @@ _vte_ft2_set_scroll(struct _vte_draw *draw, gint x, gint y)
 }
 
 const struct _vte_draw_impl _vte_draw_ft2 = {
-	"FT2",
+	"ft2",
 	_vte_ft2_check,
 	_vte_ft2_create,
 	_vte_ft2_destroy,
